<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="模板名称" prop="templateName">
        <el-input v-model="queryParams.templateName" placeholder="请输入${comment}" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>

      <el-form-item label="适用语言" prop="language">
        <el-input v-model="queryParams.language" placeholder="请输入${comment}" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item label="组别" prop="groupID">
        <el-input v-model="queryParams.groupID" placeholder="请输入${comment}" clearable @keyup.enter.native="handleQuery" />
      </el-form-item>

      <el-form-item label=" 适用院区 " prop="orgid">
        <el-input v-model="queryParams.orgid" placeholder="请输入 机构ID " clearable @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['smartor:ivrtemplate:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
          v-hasPermi="['smartor:ivrtemplate:edit']">修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
          v-hasPermi="['smartor:ivrtemplate:remove']">删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['smartor:ivrtemplate:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="ivrtemplateList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="模板名称" align="center" prop="templateName" />
      <el-table-column label="适用语言" align="center" prop="language" />
      <el-table-column label="启用状态" align="center" prop="isEnable" />
      <el-table-column label="通用库" align="center" prop="submodule" />
      <el-table-column label="标签" align="center" prop="labelInfo" />
      <el-table-column label="组别" align="center" prop="groupID" />
      <el-table-column label="适用机构" align="center" prop="orgid" />
      <el-table-column label="说明" align="center" prop="Remark" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['smartor:ivrtemplate:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['smartor:ivrtemplate:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改话术模板库对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="1000px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="12"><el-form-item label="模板名称" prop="templateName">
              <el-input v-model="form.templateName" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="组别" prop="groupID">
              <el-input v-model="form.groupID" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"> <el-form-item label="适用语言" prop="language">
              <el-input v-model="form.language" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"> <el-form-item label="静默时间（秒）" prop="silencetime">
              <el-input v-model="form.silencetime" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"> <el-form-item label="静默重播次数" prop="slienceRepeatTimes">
              <el-input v-model="form.slienceRepeatTimes" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"><el-form-item label="无匹配重播次数" prop="nomatchRepeatTimes">
              <el-input v-model="form.nomatchRepeatTimes" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label="通用库" prop="submodule">
              <el-input v-model="form.submodule" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"><el-form-item label="起始任务编号" prop="firstQuestionNum">
              <el-input v-model="form.firstQuestionNum" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"> <el-form-item label="自执行时间" prop="atuoTaskDayOffset">
              <el-input v-model="form.atuoTaskDayOffset" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="12"> <el-form-item label="启用状态" prop="isEnable">
              <el-input v-model="form.isEnable" placeholder="请输入${comment}" />
            </el-form-item></el-col>
          <el-col :span="12"><el-form-item label=" 删除标记 " prop="delFlag">
              <el-input v-model="form.delFlag" placeholder="请输入 删除标记 " />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"> <el-form-item label="适用科室" prop="DeptNames">
              <el-input v-model="form.DeptNames" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"> <el-form-item label="适用诊断" prop="icd10codename">
              <el-input v-model="form.icd10codename" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"><el-form-item label="适用机构" prop="orgid">
              <el-input v-model="form.orgid" placeholder="请输入 机构ID " />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"><el-form-item label="标签信息" prop="labelInfo">
              <el-input v-model="form.labelInfo" type="textarea" placeholder="请输入内容" />
            </el-form-item></el-col>
        </el-row>
        <el-row>
          <el-col :span="24"><el-form-item label="说明" prop="Remark">
              <el-input v-model="form.Remark" placeholder="请输入${comment}" />
            </el-form-item></el-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listIvrtemplate, getIvrtemplate, delIvrtemplate, addIvrtemplate, updateIvrtemplate } from "@/api/smartor/ivrtemplate";

export default {
  name: "Ivrtemplate",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 话术模板库表格数据
      ivrtemplateList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        templateName: null,
        silencetime: null,
        slienceRepeatTimes: null,
        nomatchRepeatTimes: null,
        firstQuestionNum: null,
        submodule: null,
        language: null,
        Remark: null,
        isEnable: null,
        isDel: null,
        addUserID: null,
        addTime: null,
        modifyUserID: null,
        modifyTime: null,
        groupID: null,
        labelInfo: null,
        submoduleID: null,
        playType: null,
        icd10code: null,
        icd10codename: null,
        atuoTaskDayOffset: null,
        DeptIds: null,
        DeptNames: null,
        fKsdm: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        templateName: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        language: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isEnable: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        isDel: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        atuoTaskDayOffset: [
          { required: true, message: "$comment不能为空", trigger: "blur" }
        ],
        delFlag: [
          { required: true, message: " 删除标记 不能为空", trigger: "blur" }
        ],
        isupload: [
          { required: true, message: " 上传标记 不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询话术模板库列表 */
    getList() {
      this.loading = true;
      listIvrtemplate(this.queryParams).then(response => {
        this.ivrtemplateList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        templateID: null,
        templateName: null,
        silencetime: null,
        slienceRepeatTimes: null,
        nomatchRepeatTimes: null,
        firstQuestionNum: null,
        submodule: null,
        language: null,
        Remark: null,
        isEnable: null,
        isDel: null,
        addUserID: null,
        addTime: null,
        modifyUserID: null,
        modifyTime: null,
        groupID: null,
        labelInfo: null,
        submoduleID: null,
        playType: null,
        icd10code: null,
        icd10codename: null,
        atuoTaskDayOffset: null,
        DeptIds: null,
        DeptNames: null,
        fKsdm: null,
        delFlag: null,
        updateBy: null,
        updateTime: null,
        createBy: null,
        createTime: null,
        isupload: null,
        uploadTime: null,
        orgid: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.templateID)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加话术模板库";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const templateID = row.templateID || this.ids
      getIvrtemplate(templateID).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改话术模板库";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.templateID != null) {
            updateIvrtemplate(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addIvrtemplate(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const templateIDs = row.templateID || this.ids;
      this.$modal.confirm('是否确认删除话术模板库编号为"' + templateIDs + '"的数据项？').then(function () {
        return delIvrtemplate(templateIDs);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => { });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('smartor/ivrtemplate/export', {
        ...this.queryParams
      }, `ivrtemplate_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
